@@ -18,46 +18,55 @@
 
 #include "obexagent.h"
 #include "receivefilejob.h"
-#include "../BlueDevilDaemon.h"
+#include "debug_p.h"
 
-#include <QIcon>
-#include <QDebug>
-#include <QDBusConnection>
+#include <QDBusObjectPath>
 
-ObexAgent::ObexAgent(QObject* parent)
-    : QDBusAbstractAdaptor(parent)
+ObexAgent::ObexAgent(QSharedPointer<BluezQt::Manager> manager, QObject *parent)
+    : BluezQt::ObexAgent(parent)
+    , m_manager(manager)
 {
-    qCDebug(BLUEDAEMON);
-    if (!QDBusConnection::sessionBus().registerObject(QStringLiteral("/BlueDevil_receiveAgent"), parent)) {
-        qDebug() << "The dbus object can't be registered";
+}
+
+QSharedPointer<BluezQt::Manager> ObexAgent::manager() const
+{
+    return m_manager;
+}
+
+bool ObexAgent::shouldAutoAcceptTransfer(const QString &address) const
+{
+    if (!m_transferTimes.contains(address)) {
+        return false;
+    }
+
+    // Auto-accept transfers from the same device within 2 seconds from last finished transfer
+    const int timeout = 2;
+    return m_transferTimes.value(address).secsTo(QDateTime::currentDateTime()) < timeout;
+}
+
+QDBusObjectPath ObexAgent::objectPath() const
+{
+    return QDBusObjectPath(QStringLiteral("/BlueDevilObexAgent"));
+}
+
+void ObexAgent::authorizePush(BluezQt::ObexTransferPtr transfer, const BluezQt::Request<QString> &request)
+{
+    qCDebug(BLUEDAEMON) << "Agent-AuthorizePush";
+
+    ReceiveFileJob *job = new ReceiveFileJob(request, transfer, this);
+    connect(job, &ReceiveFileJob::finished, this, &ObexAgent::receiveFileJobFinished);
+    job->start();
+}
+
+void ObexAgent::receiveFileJobFinished(KJob *job)
+{
+    Q_ASSERT(qobject_cast<ReceiveFileJob*>(job));
+    ReceiveFileJob *j = static_cast<ReceiveFileJob*>(job);
+
+    if (j->error()) {
+        m_transferTimes.remove(j->deviceAddress());
         return;
     }
-}
 
-ObexAgent::~ObexAgent()
-{
-
-}
-
-QString ObexAgent::AuthorizePush(const QDBusObjectPath& path, const QDBusMessage &msg)
-{
-    qCDebug(BLUEDAEMON);
-
-    msg.setDelayedReply(true);
-
-    ReceiveFileJob *job = new ReceiveFileJob(msg, path.path(), this);
-    job->start();
-
-    return QString();
-}
-
-void ObexAgent::Cancel()
-{
-    qCDebug(BLUEDAEMON);
-}
-
-
-void ObexAgent::Release()
-{
-    qCDebug(BLUEDAEMON);
+    m_transferTimes[j->deviceAddress()] = QDateTime::currentDateTime();
 }
