@@ -28,62 +28,61 @@
 #include <QVariantList>
 #include <QStringBuilder>
 
-#include <KPluginFactory>
+#include <QProcess>
 
-#include <KProcess>
+#include <KPluginFactory>
 #include <KLocalizedString>
 
-#include <bluedevil/bluedevil.h>
-
-using namespace BlueDevil;
+#include <BluezQt/Services>
 
 K_PLUGIN_FACTORY_WITH_JSON(SendFileItemActionFactory,
                            "bluedevilsendfile.json",
                            registerPlugin<SendFileItemAction>();)
 
-SendFileItemAction::SendFileItemAction(QObject* parent, const QVariantList& args)
+SendFileItemAction::SendFileItemAction(QObject *parent, const QVariantList&)
     : KAbstractFileItemActionPlugin(parent)
 {
-    Q_UNUSED(args)
+    qDBusRegisterMetaType<DeviceInfo>();
+    qDBusRegisterMetaType<QMapDeviceInfo>();
+
+    m_kded = new org::kde::BlueDevil(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/bluedevil"),
+                                     QDBusConnection::sessionBus(), this);
 }
 
-QList< QAction* > SendFileItemAction::actions(const KFileItemListProperties& fileItemInfos, QWidget* parentWidget)
+QList<QAction*> SendFileItemAction::actions(const KFileItemListProperties &infos, QWidget *parent)
 {
-    Q_UNUSED(parentWidget)
-    QList< QAction* > list;
+    Q_UNUSED(parent)
 
-    m_fileItemInfos = fileItemInfos;
+    QList<QAction*> list;
 
-    //If there is no adaptor, there is no bluetooth
-    if (!Manager::self()->usableAdapter()) {
+    // Don't show the action for files that we can't send or when Bluetooth is offline.
+    if (!infos.isLocal() || !m_kded->isOnline()) {
         return list;
     }
-    Adapter *adapter = Manager::self()->usableAdapter();
+
+    m_infos = infos;
 
     QAction *menuAction = new QAction(QIcon::fromTheme(QStringLiteral("preferences-system-bluetooth")), i18n("Send via Bluetooth"), this);
     QMenu *menu = new QMenu();
 
-    //If we have configured devices, put them first
-    QList< Device * > devices = adapter->devices();
-    if (!devices.isEmpty()) {
-        Q_FOREACH(Device *device, devices) {
-            if (device->UUIDs().contains(QLatin1String("00001105-0000-1000-8000-00805F9B34FB"), Qt::CaseInsensitive)) {
-                QAction *action = new QAction(QIcon::fromTheme(device->icon()), device->name(), this);
-                connect(action, SIGNAL(triggered(bool)), this, SLOT(deviceTriggered()));
-                action->setData(device->UBI());
-                menu->addAction(action);
-            }
+    const QMapDeviceInfo &devices = m_kded->allDevices().value();
+    Q_FOREACH (const DeviceInfo &device, devices) {
+        if (device.value(QStringLiteral("UUIDs")).contains(BluezQt::Services::ObexObjectPush)) {
+            QAction *action = new QAction(QIcon::fromTheme(device[QStringLiteral("icon")]), device.value(QStringLiteral("name")), this);
+            connect(action, &QAction::triggered, this, &SendFileItemAction::deviceTriggered);
+            action->setData(device.value(QStringLiteral("UBI")));
+            menu->addAction(action);
         }
     }
 
     QAction *otherAction = new QAction(this);
-    connect(otherAction, SIGNAL(triggered(bool)), this, SLOT(otherTriggered()));
     if (menu->actions().isEmpty()) {
         otherAction->setText(i18nc("Find Bluetooth device", "Find Device..."));
     } else {
         menu->addSeparator();
         otherAction->setText(i18nc("Other Bluetooth device", "Other..."));
     }
+    connect(otherAction, &QAction::triggered, this, &SendFileItemAction::otherTriggered);
     menu->addAction(otherAction);
 
     menuAction->setMenu(menu);
@@ -94,31 +93,26 @@ QList< QAction* > SendFileItemAction::actions(const KFileItemListProperties& fil
 void SendFileItemAction::deviceTriggered()
 {
     QStringList args;
-    args.append(QLatin1String("-u") % static_cast<QAction *>(sender())->data().toString());
+    args.append(QStringLiteral("-u") % static_cast<QAction*>(sender())->data().toString());
 
-    const QList<QUrl> &fileList = m_fileItemInfos.urlList();
-    Q_FOREACH(const QUrl &url, fileList) {
-        args.append(QLatin1String("-f") % url.path());
+    const QList<QUrl> &fileList = m_infos.urlList();
+    Q_FOREACH (const QUrl &url, fileList) {
+        args.append(QStringLiteral("-f") % url.path());
     }
-    qDebug() << args;
-    KProcess process;
-    process.setProgram(QStringLiteral("bluedevil-sendfile"), args);
-    process.startDetached();
+
+    QProcess::startDetached(QStringLiteral("bluedevil-sendfile"), args);
 }
 
 void SendFileItemAction::otherTriggered()
 {
-    qDebug();
     QStringList args;
 
-    const QList<QUrl> &fileList = m_fileItemInfos.urlList();
-    Q_FOREACH(const QUrl &url, fileList) {
-        args.append(QLatin1String("-f") % url.path());
+    const QList<QUrl> &fileList = m_infos.urlList();
+    Q_FOREACH (const QUrl &url, fileList) {
+        args.append(QStringLiteral("-f") % url.path());
     }
 
-    KProcess process;
-    process.setProgram(QStringLiteral("bluedevil-sendfile"), args);
-    process.startDetached();
+    QProcess::startDetached(QStringLiteral("bluedevil-sendfile"), args);
 }
 
 #include "sendfileitemaction.moc"
