@@ -26,41 +26,42 @@
 #include <QObject>
 #include <QWizard>
 #include <QStringList>
+
+#include <BluezQt/Manager>
+
 #include "discoverwidget.h"
 
-class WizardAgent;
-class QStringList;
 class SendFilesJob;
-namespace BlueDevil {
-    class Device;
-}
-using namespace BlueDevil;
 
 class SendFileWizard : public QWizard
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    SendFileWizard(const QString &deviceUBI, const QStringList &files);
-    virtual ~SendFileWizard();
+    explicit SendFileWizard(const QString &device, const QStringList &files);
+    ~SendFileWizard();
 
-    virtual void done(int result);
+    void done(int result) Q_DECL_OVERRIDE;
 
+    BluezQt::Manager *manager() const;
+
+    QStringList files() const;
     void setFiles(const QStringList &files);
 
-    void setDevice(Device *device);
-    void setDevice(QString deviceUrl);
-    Device* device();
+    BluezQt::DevicePtr device() const;
+    void setDevice(BluezQt::DevicePtr device);
 
     void startTransfer();
 
 private Q_SLOTS:
-    void wizardDone();
+    void initJobResult(BluezQt::InitManagerJob *job);
 
 private:
-    QStringList  m_files;
+    QString m_deviceUrl;
+    QStringList m_files;
 
-    Device       *m_device;
+    BluezQt::Manager *m_manager;
+    BluezQt::DevicePtr m_device;
     SendFilesJob *m_job;
 };
 
